@@ -122,8 +122,10 @@ class mcDETECT:
                     continue
                 temp_in_nucleus = np.sum(target["overlaps_nucleus"].values[mask])
                 temp_size = coords.shape[0]
-                coords_unique = np.unique(coords, axis=0)
-                center, r2 = miniball.get_bounding_ball(coords_unique, epsilon=1e-8)
+                # coords_unique = np.unique(coords, axis=0)
+                temp = pd.DataFrame(coords, columns=["global_x", "global_y", "global_z"])
+                temp = temp.drop_duplicates()
+                center, r2 = miniball.get_bounding_ball(np.array(temp), epsilon=1e-8)
                 if self.type != "Xenium":
                     closest_z = closest(z_grid, center[2])
                 else:
@@ -290,10 +292,10 @@ class mcDETECT:
     
     
     # [MAIN] dataframe, granule metadata
-    def detect(self):
-        
-        _, data_low, data_high = self.dbscan()
-        
+    def detect(self, record_cell_id = False):
+
+        _, data_low, data_high = self.dbscan(record_cell_id = record_cell_id)
+
         print("Merging spheres...")
         sphere_low, sphere_high = self.merge_sphere(data_low), self.merge_sphere(data_high)
         
